﻿using System;
using System.Globalization;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            Loaded += Window_Loaded;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            BitmapImage bitmapImage = new BitmapImage();

            bitmapImage.BeginInit();

            bitmapImage.DecodePixelWidth = 300;
            bitmapImage.UriSource        = GetResourceURI(null, "IMAGE/sample.jpg");

            bitmapImage.EndInit();

            FormattedText formattedText = new FormattedText
            (
                "수련",
                new CultureInfo("ko-kr"),
                FlowDirection.LeftToRight,
                new Typeface
                (
                    FontFamily,
                    FontStyles.Normal,
                    FontWeights.Bold,
                    new FontStretch()
                ),
                32,
                Brushes.White
            );

            DrawingVisual drawingVisual = new DrawingVisual();

            DrawingContext drawingContext = drawingVisual.RenderOpen();

            drawingContext.DrawImage
            (
                bitmapImage,
                new Rect
                (
                    0,
                    0,
                    bitmapImage.Width,
                    bitmapImage.Height
                )
            ); 

            drawingContext.DrawText
            (
                formattedText,
                new Point((bitmapImage.Width - formattedText.Width) / 2 , 10)
            );

            drawingContext.Close();

            RenderTargetBitmap renderTargetBitmap = new RenderTargetBitmap
            (
                bitmapImage.PixelWidth,
                bitmapImage.PixelHeight,
                96,
                96,
                PixelFormats.Pbgra32
            );

            renderTargetBitmap.Render(drawingVisual);

            this.image.Source = renderTargetBitmap;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 리소스 URI 구하기 - GetResourceURI(assemblyName, resourcePath)

        /// <summary>
        /// 리소스 URI 구하기
        /// </summary>
        /// <param name="assemblyName">어셈블리명</param>
        /// <param name="resourcePath">리소스 경로</param>
        /// <returns>리소스 URI</returns>
        private Uri GetResourceURI(string assemblyName, string resourcePath)
        {
            if(string.IsNullOrEmpty(assemblyName))
            {
                return new Uri(string.Format("pack://application:,,,/{0}", resourcePath));
            }
            else
            {
                return new Uri(string.Format("pack://application:,,,/{0};component/{1}", assemblyName, resourcePath));
            }
        }

        #endregion
    }
}